@@ -1,7 +1,6 @@
-from .sylia import Clock as clock, Screen as screen, init
+from .sylia import Clock as clock, Screen as screen, Duck as duck, init
 from .sylia import Sound as sound, Key as key, Mouse as mouse, running
 
 from .image import Image as image
 from .shape import Shape as shape
-from .text import Text as text
-from .duck import Duck as duck
\ No newline at end of file
+from .text import Text as text
\ No newline at end of file
