@@ -25,8 +25,11 @@ class RenderObject:
         self.angle = angle
 
     def setScale(self, size):
-        if(len(size) != 2):
-            raise Exception("Error: size expects an array with two elements [width, height]")
+        try:
+            if(len(size) != 2):
+                raise Exception("Error: setScale expects an array with two elements [width, height]")
+        except:
+            raise Exception("Error: setScale expects an array with two elements [width, height]")
         self.size = size
 
     def render(self):
@@ -36,7 +39,9 @@ class RenderObject:
             return
         # Check if image is scaled (otherwise do not scale)  
         if(self.size):
-            self.image = pygame.transform.scale(self.image, (int(self.rect.width*self.size[0]), int(self.rect.height*self.size[1])))
-        image = pygame.transform.rotate(self.image, -self.angle)
+            image = pygame.transform.scale(self.image, (int(self.rect.width*self.size[0]), int(self.rect.height*self.size[1])))
+            image = pygame.transform.rotate(image, self.angle)
+        else:
+            image = pygame.transform.rotate(self.image, self.angle)
         rect = image.get_rect(center=self.rect.center)
         RenderObject.surface.blit(image, rect)
